@@ -1078,8 +1078,10 @@ main_window_closed_cb (GtkWidget *dialog, gpointer user_data)
 	gs_shell_clean_back_entry_stack (shell);
 	gtk_widget_hide (dialog);
 
-	/* Free unused memory */
+#ifdef __GLIBC__
+	/* Free unused memory with GNU extension of malloc.h */
 	malloc_trim (0);
+#endif
 
 	return TRUE;
 }
